@@ -112,6 +112,8 @@ struct _EogImageClass {
 
 	void (* next_frame)        (EogImage *img,
 				    gint delay);
+
+	void (* file_changed)      (EogImage *img);
 };
 
 GType	          eog_image_get_type	             (void) G_GNUC_CONST;
@@ -209,6 +211,10 @@ RsvgHandle       *eog_image_get_svg                  (EogImage *img);
 EogTransform     *eog_image_get_transform            (EogImage *img);
 #endif
 
+void              eog_image_file_changed             (EogImage *img);
+
+gboolean          eog_image_is_file_changed          (EogImage *img);
+
 G_END_DECLS
 
 #endif /* __EOG_IMAGE_H__ */
