@@ -1,4 +1,4 @@
-/* Eye of Gnome - Statusbar 
+/* Eye of Gnome - Statusbar
  *
  * Copyright (C) 2000-2006 The Free Software Foundation
  *
@@ -35,7 +35,7 @@
 
 G_DEFINE_TYPE (EogStatusbar, eog_statusbar, GTK_TYPE_STATUSBAR)
 
-struct _EogStatusbarPrivate 
+struct _EogStatusbarPrivate
 {
 	GtkWidget *progressbar;
 	GtkWidget *img_num_statusbar;
@@ -58,33 +58,30 @@ eog_statusbar_init (EogStatusbar *statusbar)
 	statusbar->priv = EOG_STATUSBAR_GET_PRIVATE (statusbar);
 	priv = statusbar->priv;
 
-	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (statusbar), TRUE);
-
 	priv->img_num_statusbar = gtk_statusbar_new ();
-	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (priv->img_num_statusbar), FALSE);
 	gtk_widget_set_size_request (priv->img_num_statusbar, 100, 10);
 	gtk_widget_show (priv->img_num_statusbar);
 
 	gtk_box_pack_end (GTK_BOX (statusbar),
 			  priv->img_num_statusbar,
-			  FALSE, 
-			  TRUE, 
+			  FALSE,
+			  TRUE,
 			  0);
 
 	vbox = gtk_vbox_new (FALSE, 0);
 
 	gtk_box_pack_end (GTK_BOX (statusbar),
 			  vbox,
-			  FALSE, 
-			  FALSE, 
+			  FALSE,
+			  FALSE,
 			  2);
 
 	statusbar->priv->progressbar = gtk_progress_bar_new ();
 
 	gtk_box_pack_end (GTK_BOX (vbox),
 			  priv->progressbar,
-			  TRUE, 
-			  TRUE, 
+			  TRUE,
+			  TRUE,
 			  2);
 
 	gtk_widget_set_size_request (priv->progressbar, -1, 10);
@@ -112,7 +109,17 @@ eog_statusbar_set_image_number (EogStatusbar *statusbar,
 
 	gtk_statusbar_pop (GTK_STATUSBAR (statusbar->priv->img_num_statusbar), 0);
 
-	msg = g_strdup_printf ("%d / %d", num, tot);
+	/* Translators: This string is displayed in the statusbar.
+	 * The first token is the image number, the second is total image
+	 * count.
+	 *
+	 * Translate to "%Id" if you want to use localized digits, or
+	 * translate to "%d" otherwise.
+	 *
+	 * Note that translating this doesn't guarantee that you get localized
+	 * digits. That needs support from your system and locale definition
+	 * too.*/
+	msg = g_strdup_printf (_("%d / %d"), num, tot);
 
 	gtk_statusbar_push (GTK_STATUSBAR (statusbar->priv->img_num_statusbar), 0, msg);
 
